#
# spec file for package python-pyftpdlib
#
# Copyright (c) 2020 SUSE LLC
# Copyright (c) 2016 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# Tests randomly fail: https://github.com/giampaolo/pyftpdlib/issues/386
%bcond_with     test
%bcond_without python2
Name:           python-pyftpdlib
Version:        1.5.6
Release:        bp153.1.18
Summary:        Asynchronous FTP server library for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/giampaolo/pyftpdlib/
Source:         https://files.pythonhosted.org/packages/source/p/pyftpdlib/pyftpdlib-%{version}.tar.gz
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pyOpenSSL}
BuildRequires:  %{python_module pysendfile}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pyOpenSSL
Recommends:     python-pysendfile
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python-ipaddress
BuildRequires:  python-mock
%endif
%ifpython2
Requires:       python-ipaddress
%endif
%python_subpackages

%description
The Python FTP server library provides a high-level interface to
write very asynchronous FTP servers with Python.

%prep
%setup -q -n pyftpdlib-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# Note: Do not remove tests. Other packages import them

%if %{with test}
%check
export PYTHONPATH=$PWD
%python_exec pyftpdlib/test/runner.py
%endif

%files %{python_files}
%license LICENSE
%doc README.rst
%python3_only %{_bindir}/ftpbench
%{python_sitelib}/*

%changelog
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Fri Mar 27 2020 Antonio Larrosa <alarrosa@suse.com>
- Do not remove tests, other packages import them
* Wed Mar 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.6:
  - #467: added pre-fork concurrency model, spawn()ing worker processes to split
    load.
  - #520: directory LISTing is now 3.7x times faster.
* Tue May 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Do not remove tests, other packages import them
* Sat May 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.5.5:
  * Various minor fixes and documentation updates
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed May  9 2018 toddrme2178@gmail.com
- Version update to 1.5.4
  + Enhancements
  * #463: FTPServer class can now be used as a context manager.
  + Bug fixes
  * #431: Ctrl-C doesn't exit `python -m pyftpdlib` on Windows.
  * #436: ThreadedFTPServer.max_cons is evaluated threading.activeCount(). If
    the user uses threads of its own it will consume the number of max_cons.
  * #447: ThreadedFTPServer and MultiprocessFTPServer do not join() tasks which
    are no longer consuming resources.
- Disable tests since they randomly fail.
  See https://github.com/giampaolo/pyftpdlib/issues/386
* Wed May  2 2018 tchvatal@suse.com
- Version update to 1.5.3:
  * implemented SITE MFMT command which changes file modification time. (patch by Tahir Ijaz)
  * add username and password command line options
  * documentation moved to readthedocs: http://pyftpdlib.readthedocs.io
  * fix duplicated output log. (path by PonyPC)
  * Respond successfully to STOR only after closing file handle.
* Thu Jul  6 2017 jengelh@inai.de
- Trim exaggeration from descriptions.
* Thu Jun 22 2017 jmatejek@suse.com
- update to 1.5.2
  * disables old SSL methods
  * fixed some hangs/crashes
- fixes test failures in OBS
- drop patches that are no longer needed:
  * pyftpdlib-disable-error-0-ssl-unwrap.diff
  * pyftpdlib-disable-incomplete-file-received.diff
  * pyftpdlib-handle-missing-SSLv3.diff
- convert to singlespec
* Mon May  9 2016 hpj@urpla.net
- add patch to disable another failing test, related to icomplete
  file receptions
* Mon May  9 2016 hpj@urpla.net
- add patch to test SSLv3 only, if available
* Mon May  9 2016 hpj@urpla.net
- add patch to disable a test, that triggers an error 0 in ssl
* Sun May  8 2016 hpj@urpla.net
- version 1.5.1: initial build
